"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const i18n_context_1 = require("../i18n.context");
exports.I18n = common_1.createParamDecorator((data, ctx) => {
    switch (ctx.getType()) {
        case 'http':
            return new i18n_context_1.I18nContext(...resolveI18nServiceFromRestRequest(ctx.switchToHttp().getRequest()));
        case 'graphql':
            return new i18n_context_1.I18nContext(...resolveI18nServiceFromGraphQLContext(ctx.getArgs()));
        default:
            throw Error(`context type: ${ctx.getType()} not supported`);
    }
});
function resolveI18nServiceFromRestRequest(req) {
    return [
        req.i18nLang || (req.raw ? req.raw.i18nLang : undefined),
        req.i18nService || (req.raw ? req.raw.i18nService : undefined),
    ];
}
function resolveI18nServiceFromGraphQLContext(req) {
    const [root, args, ctx, info] = req;
    return [ctx.req.i18nLang, ctx.req.i18nService];
}
//# sourceMappingURL=i18n.decorator.js.map